# django-islands

Oficial fork of [django-multitenant](https://github.com/citusdata/django-multitenant/) under development and maintenance.

## Installation

Install using `pip`

```bash
pip install django_islands

```

## Supported Django versions/Pre-requisites.

| Python                 | Django        |
| -----------------------| --------------|
| 3.8 3.9 3.10 3.11 3.12 | 5.x           |
| 3.8 3.9 3.10 3.11      | 4.x           |
| 3.8 3.9 3.10 3.11      | 4.0           |
| 3.7                    | 3.2           |

## Warning

I haven't had much time to develop this project lately, but you can be sure that it is still under development! If you have any questions, suggestions for improvements or functionality or want to report a bug, feel free to contact me and I will try to fix the problem within 7 days.
